java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.eclipse.serializer.exceptions.BaseException
org.eclipse.serializer.com.ComException
org.eclipse.serializer.communication.binarydynamic.ComExceptionRemoteClassNotFound
All Implemented Interfaces:
Serializable

public class ComExceptionRemoteClassNotFound extends org.eclipse.serializer.com.ComException
Thrown when a typeDefinition received from the remote host contains a type that can't be resolved to an exiting class on the local system.
See Also:
  • Constructor Details

    • ComExceptionRemoteClassNotFound

      public ComExceptionRemoteClassNotFound(String typeName)
      Constructs a ComExceptionRemoteClassNotFound with no detail message.
      Parameters:
      typeName - the type name of the missing class