Package org.eclipse.serializer.communication.binarydynamic
package org.eclipse.serializer.communication.binarydynamic
-
ClassDescriptionThrown when a typeDefinition received from the remote host contains a type that can't be resolved to an exiting class on the local system.ComHandlerReceive<T extends ComMessage>ComHandlerSend<T extends ComMessage>This class handles the matching of types that have been modified on either the client or the host side Including the necessary data transfer during the initialization of the ComChannels.