All Classes and Interfaces
Class
Description
Thrown when a typeDefinition received from the remote host
contains a type that can't be resolved to an exiting class
on the local system.
This class handles the matching of types that have been modified on either the client or the host side
Including the necessary data transfer during the initialization of the ComChannels.
returns a null secureRandom to use the system default SecureRandom
uses system default key manager
Provide a PKCS12 KeyManger
Provides a nearly empty SSLParameters object.
uses system default trust manager
Provide a PKCS12 TrustManager